@@ -1101,7 +1101,7 @@ class SubstrateClient:
                         )
                     elif "Other" in dispatch_error:
                         extrinsic_receipt.error_message = ExtrinsicReceiptErrorMessage(
-                            type="System",
+                            type="Arithmetic",
                             name="Other",
                             docs=["Unspecified error occurred"],
                         )
@@ -1145,6 +1145,50 @@ class SubstrateClient:
                                     docs=["Unspecified token error occurred"],
                                 )
                             )
+                    elif "Arithmetic" in dispatch_error:
+                        if isinstance(dispatch_error["Arithmetic"], str):
+                            error_name = dispatch_error["Arithmetic"]
+                            # Recherche dans le registre portable pour ArithmeticError
+                            for metadata_type in self.metadata.portable_registry.value[
+                                "types"
+                            ]:
+                                type_path = metadata_type.get("type").get("path")
+                                if type_path == ["sp_arithmetic", "ArithmeticError"]:
+                                    for variant in (
+                                        metadata_type.get("type")
+                                        .get("def")
+                                        .get("variant")
+                                        .get("variants")
+                                    ):
+                                        if variant["name"] == error_name:
+                                            extrinsic_receipt.error_message = ExtrinsicReceiptErrorMessage(
+                                                type="Arithmetic",
+                                                name=error_name,
+                                                docs=variant.get("docs")
+                                                or [f"Arithmetic error: {error_name}"],
+                                            )
+                                            break
+                                    else:
+                                        continue
+                                    break
+                            else:
+                                # Fallback si non trouvé
+                                extrinsic_receipt.error_message = (
+                                    ExtrinsicReceiptErrorMessage(
+                                        type="Arithmetic",
+                                        name=error_name,
+                                        docs=[f"Arithmetic error: {error_name}"],
+                                    )
+                                )
+                        else:
+                            # Format inattendu
+                            extrinsic_receipt.error_message = (
+                                ExtrinsicReceiptErrorMessage(
+                                    type="Arithmetic",
+                                    name="Unknown",
+                                    docs=["Unknown arithmetic error occurred"],
+                                )
+                            )
                 elif (
                     event["module_id"] == "Utility"
                     and event["event_id"] == "BatchInterrupted"
@@ -1188,7 +1232,40 @@ class SubstrateClient:
                                     docs=[error_name],
                                 )
                             )
-
+                    elif "Arithmetic" in error:
+                        error_name = error.get("Arithmetic")
+                        for metadata_type in self.metadata.portable_registry.value[
+                            "types"
+                        ]:
+                            type_path = metadata_type.get("type").get("path")
+                            if type_path == ["sp_arithmetic", "ArithmeticError"]:
+                                for variant in (
+                                    metadata_type.get("type")
+                                    .get("def")
+                                    .get("variant")
+                                    .get("variants")
+                                ):
+                                    if variant["name"] == error_name:
+                                        extrinsic_receipt.error_message = (
+                                            ExtrinsicReceiptErrorMessage(
+                                                type="Arithmetic",
+                                                name=error_name,
+                                                docs=variant.get("docs")
+                                                or [f"Arithmetic error: {error_name}"],
+                                            )
+                                        )
+                                        break
+                                else:
+                                    continue
+                                break
+                        if extrinsic_receipt.error_message is None:
+                            extrinsic_receipt.error_message = (
+                                ExtrinsicReceiptErrorMessage(
+                                    type="Arithmetic",
+                                    name=error_name,
+                                    docs=[error_name],
+                                )
+                            )
                 elif not has_transaction_fee_paid_event:
 
                     if (
