@@ -33,6 +33,14 @@ class AccountCryptoType(int, Enum):
     ECDSA = 2
 
 
+@dataclass
+class AccountBalance:
+
+    total: int
+    available: int
+    reserved: int
+
+
 @dataclass
 class Account:
 
@@ -40,6 +48,8 @@ class Account:
     name: Optional[str] = None
     crypto_type: AccountCryptoType = AccountCryptoType.ED25519
     balance: Optional[int] = None
+    balance_available: Optional[int] = None
+    balance_reserved: Optional[int] = None
     path: Optional[str] = None
     root: Optional[str] = None
     file_import: bool = False
