@@ -90,6 +90,18 @@ class IndexersEvent(EventInterface):
     EVENT_TYPE_LIST_CHANGED: ClassVar[str] = f"{__qualname__}.list_changed"  # type: ignore
 
 
+@dataclass
+class DataPodsEvent(EventInterface):
+    """
+    DataPodsEvent class
+    """
+
+    type: str
+
+    # type ignore required because mypy bug https://github.com/python/mypy/issues/6473
+    EVENT_TYPE_LIST_CHANGED: ClassVar[str] = f"{__qualname__}.list_changed"  # type: ignore
+
+
 @dataclass
 class ConnectionsEvent(EventInterface):
     """
@@ -103,6 +115,8 @@ class ConnectionsEvent(EventInterface):
     EVENT_TYPE_NODE_DISCONNECTED: ClassVar[str] = f"{__qualname__}.node_disconnected"  # type: ignore
     EVENT_TYPE_INDEXER_CONNECTED: ClassVar[str] = f"{__qualname__}.indexer_connected"  # type: ignore
     EVENT_TYPE_INDEXER_DISCONNECTED: ClassVar[str] = f"{__qualname__}.indexer_disconnected"  # type: ignore
+    EVENT_TYPE_DATAPOD_CONNECTED: ClassVar[str] = f"{__qualname__}.datapod_connected"  # type: ignore
+    EVENT_TYPE_DATAPOD_DISCONNECTED: ClassVar[str] = f"{__qualname__}.datapod_disconnected"  # type: ignore
 
 
 @dataclass
