@@ -13,10 +13,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 from dataclasses import dataclass
+from enum import Enum
+from typing import Optional
 
-STATUS_CREATED = "Created"
-STATUS_CONFIRMED = "Confirmed"
-STATUS_VALIDATED = "Validated"
+
+class IdentityStatus(int, Enum):
+    UNCONFIRMED = 0
+    UNVALIDATED = 1
+    MEMBER = 2
+    NOT_MEMBER = 3
+    REVOKED = 4
 
 
 @dataclass
@@ -24,4 +30,17 @@ class Identity:
     index: int
     removable_on: int
     next_creatable_on: int
-    status: str
+    status: IdentityStatus
+    address: str
+    old_address: Optional[str]
+    first_eligible_ud: int
+    name: Optional[str]
+
+
+@dataclass
+class Certification:
+    issuer_identity_index: int
+    issuer_address: str
+    receiver_identity_index: int
+    receiver_address: str
+    expire_on_block: int
