@@ -34,9 +34,9 @@ class Indexer(ServerInterface):
 
     def __eq__(self, other):
         """
-        Test equality on peer_id
+        Test equality on url
 
-        :param other: Node instance
+        :param other: Indexer instance
         :return:
         """
         if not isinstance(other, self.__class__):
