@@ -208,6 +208,12 @@ class Identities:
                 )
             stored_identity = self.get(identity.index)
             if stored_identity is not None:
+                if (
+                    identity.name is None
+                    and stored_identity.name is not None
+                    and stored_identity.index == identity.index
+                ):
+                    identity.name = stored_identity.name
                 self.update(identity)
             else:
                 self.add(identity)
@@ -236,14 +242,30 @@ class Identities:
         :return:
         """
         identities = self.network_get_identities(addresses)
+        names: Dict[int, str] = {}
+        if self.indexer_identities.indexer.connection.is_connected():
+            names = self.indexer_identities.get_identity_names(
+                [
+                    identity.index
+                    for identity in identities.values()
+                    if identity is not None
+                ]
+            )
         for address, identity in identities.items():
             if identity is None:
                 old_identity = self.get_by_address(address)
                 if old_identity is not None:
                     self.delete(old_identity.index)
             else:
+                identity.name = names.get(identity.index, None)
                 stored_identity = self.get(identity.index)
                 if stored_identity is not None:
+                    if (
+                        identity.name is None
+                        and stored_identity.name is not None
+                        and stored_identity.index == identity.index
+                    ):
+                        identity.name = stored_identity.name
                     self.update(identity)
                 else:
                     self.add(identity)
