@@ -18,6 +18,8 @@ import abc
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
+    from interfaces.adapters.network.datapod.datapod import NetworkDataPodInterface
+
     from tikka.interfaces.adapters.network.indexer.indexer import (
         NetworkIndexerInterface,
     )
@@ -47,6 +49,15 @@ class NetworkInterface(abc.ABC):
         """
         raise NotImplementedError
 
+    @property
+    def datapod(self) -> NetworkDataPodInterface:
+        """
+        Return NetworkDataPodInterface instance
+
+        :return:
+        """
+        raise NotImplementedError
+
 
 class NetworkException(Exception):
     """
