@@ -25,15 +25,16 @@ class AccountsRepositoryInterface(abc.ABC):
     AccountRepositoryInterface class
     """
 
-    COLUMN_ADDRESS = "address"
-    COLUMN_NAME = "name"
-    COLUMN_CRYPTO_TYPE = "crypto_type"
-    COLUMN_BALANCE = "balance"
-    COLUMN_IDENTITY_INDEX = "identity_index"
-    COLUMN_PATH = "path"
-    COLUMN_ROOT = "root"
-    COLUMN_FILE_IMPORT = "file_import"
-    COLUMN_CATEGORY_ID = "category_id"
+    COLUMN_ADDRESS = "account_address"
+    COLUMN_NAME = "account_name"
+    COLUMN_CRYPTO_TYPE = "account_crypto_type"
+    COLUMN_BALANCE = "account_balance"
+    COLUMN_PATH = "account_path"
+    COLUMN_ROOT = "account_root"
+    COLUMN_FILE_IMPORT = "account_file_import"
+    COLUMN_CATEGORY_ID = "account_category_id"
+    COLUMN_LEGACY_V1 = "account_legacy_v1"
+    COLUMN_TOTAL_TRANSFERS_COUNT = "account_total_transfers_count"
 
     SORT_ORDER_ASCENDING = "ASC"
     SORT_ORDER_DESCENDING = "DESC"
@@ -45,12 +46,14 @@ class AccountsRepositoryInterface(abc.ABC):
     class TableViewRow:
         wallet_address: Optional[str]
         identity_index: Optional[int]
-        balance: int
+        identity_name: Optional[str]
+        balance: Optional[int]
         name: Optional[str]
         address: str
         path: Optional[str]
         root: Optional[str]
         crypto_type: int
+        legacy_v1: bool
         category_name: Optional[str]
 
     @abc.abstractmethod
@@ -107,11 +110,20 @@ class AccountsRepositoryInterface(abc.ABC):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def delete(self, account: Account) -> None:
+    def delete(self, address: str) -> None:
         """
-        Delete account in repository
+        Delete account with address in repository
+
+        :param address: Account address
+        :return:
+        """
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def delete_all(self) -> None:
+        """
+        Delete all accounts
 
-        :param account: Account instance to delete
         :return:
         """
         raise NotImplementedError
@@ -124,3 +136,12 @@ class AccountsRepositoryInterface(abc.ABC):
         :return:
         """
         raise NotImplementedError
+
+    @abc.abstractmethod
+    def total_balance(self) -> int:
+        """
+        Return total sum of all account balances
+
+        :return:
+        """
+        raise NotImplementedError
