@@ -20,24 +20,35 @@ from PyQt5.QtCore import QAbstractItemModel, QLocale, QModelIndex, Qt, QVariant
 from PyQt5.QtGui import QFont, QIcon, QPixmap
 
 from tikka.domains.application import Application
+from tikka.domains.entities.account import Account
 from tikka.domains.entities.constants import AMOUNT_UNIT_KEY
-from tikka.domains.entities.identity import STATUS_VALIDATED
+from tikka.domains.entities.identity import IdentityStatus
+from tikka.domains.entities.smith import SmithStatus
 from tikka.interfaces.adapters.repository.accounts import AccountsRepositoryInterface
-from tikka.interfaces.adapters.repository.preferences import (
-    SELECTED_UNIT,
-    TABLE_CATEGORY_FILTER,
-    TABLE_SORT_COLUMN,
-    TABLE_SORT_ORDER,
-    TABLE_WALLET_FILTER,
+from tikka.interfaces.adapters.repository.categories import (
+    CategoriesRepositoryInterface,
+)
+from tikka.interfaces.adapters.repository.identities import (
+    IdentitiesRepositoryInterface,
 )
 from tikka.slots.pyqt.entities.constants import (
+    ACCOUNTS_TABLE_CATEGORY_FILTER_PREFERENCES_KEY,
+    ACCOUNTS_TABLE_SORT_COLUMN_PREFERENCES_KEY,
+    ACCOUNTS_TABLE_SORT_ORDER_PREFERENCES_KEY,
+    ACCOUNTS_TABLE_WALLET_FILTER_PREFERENCES_KEY,
     ADDRESS_MONOSPACE_FONT_NAME,
     ICON_ACCOUNT_NO_WALLET,
     ICON_ACCOUNT_WALLET_LOCKED,
     ICON_ACCOUNT_WALLET_UNLOCKED,
-    ICON_IDENTITY,
+    ICON_IDENTITY_MEMBER,
+    ICON_IDENTITY_MEMBER_NOT_VALIDATED,
+    ICON_IDENTITY_NOT_MEMBER,
+    ICON_SMITH,
+    SELECTED_UNIT_PREFERENCES_KEY,
 )
 
+BalanceStyledRole = Qt.UserRole + 1001
+
 
 class AccountTableModel(QAbstractItemModel):
     """
@@ -46,14 +57,15 @@ class AccountTableModel(QAbstractItemModel):
 
     REPOSITORY_COLUMNS = [
         "",
-        AccountsRepositoryInterface.COLUMN_IDENTITY_INDEX,
-        AccountsRepositoryInterface.COLUMN_BALANCE,
+        IdentitiesRepositoryInterface.COLUMN_NAME,
         AccountsRepositoryInterface.COLUMN_NAME,
+        AccountsRepositoryInterface.COLUMN_BALANCE,
         AccountsRepositoryInterface.COLUMN_ADDRESS,
         AccountsRepositoryInterface.COLUMN_PATH,
         AccountsRepositoryInterface.COLUMN_ROOT,
         AccountsRepositoryInterface.COLUMN_CRYPTO_TYPE,
-        AccountsRepositoryInterface.COLUMN_CATEGORY_ID,
+        AccountsRepositoryInterface.COLUMN_LEGACY_V1,
+        CategoriesRepositoryInterface.COLUMN_NAME,
     ]
 
     def __init__(self, application: Application, locale: QLocale):
@@ -64,8 +76,22 @@ class AccountTableModel(QAbstractItemModel):
         # get parent widget locale to localize balance display
         self.locale = locale
 
+        self.display_identity_icon = {
+            IdentityStatus.UNCONFIRMED.value: QPixmap(
+                ICON_IDENTITY_MEMBER_NOT_VALIDATED
+            ),
+            IdentityStatus.UNVALIDATED.value: QPixmap(
+                ICON_IDENTITY_MEMBER_NOT_VALIDATED
+            ),
+            IdentityStatus.MEMBER.value: QPixmap(ICON_IDENTITY_MEMBER),
+            IdentityStatus.NOT_MEMBER.value: QPixmap(ICON_IDENTITY_NOT_MEMBER),
+            IdentityStatus.REVOKED.value: QPixmap(ICON_IDENTITY_NOT_MEMBER),
+        }
+
         # calculate balance display by unit preference
-        unit_preference = self.application.preferences_repository.get(SELECTED_UNIT)
+        unit_preference = self.application.repository.preferences.get(
+            SELECTED_UNIT_PREFERENCES_KEY
+        )
         if unit_preference is not None:
             self.amount = self.application.amounts.get_amount(unit_preference)
         else:
@@ -88,32 +114,34 @@ class AccountTableModel(QAbstractItemModel):
         :return:
         """
         # calculate balance display by unit preference
-        unit_preference = self.application.preferences_repository.get(SELECTED_UNIT)
+        unit_preference = self.application.repository.preferences.get(
+            SELECTED_UNIT_PREFERENCES_KEY
+        )
         if unit_preference is not None:
             self.amount = self.application.amounts.get_amount(unit_preference)
         else:
             self.amount = self.application.amounts.get_amount(AMOUNT_UNIT_KEY)
 
-        sort_column_index = self.application.preferences_repository.get(
-            TABLE_SORT_COLUMN
+        sort_column_index = self.application.repository.preferences.get(
+            ACCOUNTS_TABLE_SORT_COLUMN_PREFERENCES_KEY
         )
         if sort_column_index is not None:
             sort_column_index = int(sort_column_index)
-        repository_sort_order = self.application.preferences_repository.get(
-            TABLE_SORT_ORDER
+        repository_sort_order = self.application.repository.preferences.get(
+            ACCOUNTS_TABLE_SORT_ORDER_PREFERENCES_KEY
         )
 
         filters = {}
-        category_id_filter = self.application.preferences_repository.get(
-            TABLE_CATEGORY_FILTER
+        category_id_filter = self.application.repository.preferences.get(
+            ACCOUNTS_TABLE_CATEGORY_FILTER_PREFERENCES_KEY
         )
         if category_id_filter is not None:
             filters[
                 AccountsRepositoryInterface.TABLE_VIEW_FILTER_BY_CATEGORY_ID
             ] = category_id_filter
 
-        wallet_filter_preference = self.application.preferences_repository.get(
-            TABLE_WALLET_FILTER
+        wallet_filter_preference = self.application.repository.preferences.get(
+            ACCOUNTS_TABLE_WALLET_FILTER_PREFERENCES_KEY
         )
         if wallet_filter_preference is not None:
             # preference store boolean as integer in a string column ("0" or "1")
@@ -249,29 +277,39 @@ class AccountTableModel(QAbstractItemModel):
                 )
             else:
                 data = QVariant(QIcon(QPixmap(ICON_ACCOUNT_NO_WALLET)))
-        elif (
-            index.column()
-            == AccountTableModel.REPOSITORY_COLUMNS.index(
-                AccountsRepositoryInterface.COLUMN_IDENTITY_INDEX
-            )
-            and role == Qt.DecorationRole
+        elif index.column() == AccountTableModel.REPOSITORY_COLUMNS.index(
+            IdentitiesRepositoryInterface.COLUMN_NAME
         ):
-            if table_view_row.identity_index is not None:
-                identity = self.application.identities.get(
-                    table_view_row.identity_index
-                )
-                if identity is not None and identity.status == STATUS_VALIDATED:
-                    data = QVariant(
-                        QPixmap(ICON_IDENTITY).scaled(
-                            16, 16, aspectRatioMode=Qt.KeepAspectRatio
+            identity = self.application.identities.get_by_address(
+                table_view_row.address
+            )
+            if identity is not None:
+                if role == Qt.DecorationRole:
+                    smith = self.application.smiths.get(identity.index)
+                    if smith is not None and smith.status == SmithStatus.SMITH:
+                        data = QVariant(
+                            QPixmap(ICON_SMITH).scaled(
+                                16, 18, aspectRatioMode=Qt.KeepAspectRatio
+                            )
                         )
-                    )
+                    else:
+                        data = QVariant(
+                            self.display_identity_icon[identity.status.value].scaled(
+                                16, 18, aspectRatioMode=Qt.KeepAspectRatio
+                            )
+                        )
+                if role == Qt.DisplayRole:
+                    if identity.name is not None:
+                        data = QVariant(f"{identity.name}#{identity.index}")
+                    else:
+                        data = QVariant(f"#{identity.index}")
+
         elif (
             index.column()
             == AccountTableModel.REPOSITORY_COLUMNS.index(
                 AccountsRepositoryInterface.COLUMN_BALANCE
             )
-            and role == Qt.DisplayRole
+            and role == BalanceStyledRole
             and table_view_row.balance is not None
         ):
             data = QVariant(
@@ -321,7 +359,20 @@ class AccountTableModel(QAbstractItemModel):
         elif (
             index.column()
             == AccountTableModel.REPOSITORY_COLUMNS.index(
-                AccountsRepositoryInterface.COLUMN_CATEGORY_ID
+                AccountsRepositoryInterface.COLUMN_LEGACY_V1
+            )
+            and role == Qt.DisplayRole
+            and table_view_row.legacy_v1 is True
+        ):
+            data = QVariant(
+                Account(table_view_row.address).get_v1_address(
+                    self.application.currencies.get_current().ss58_format
+                )
+            )
+        elif (
+            index.column()
+            == AccountTableModel.REPOSITORY_COLUMNS.index(
+                CategoriesRepositoryInterface.COLUMN_NAME
             )
             and role == Qt.DisplayRole
         ):
@@ -356,7 +407,7 @@ class AccountTableModel(QAbstractItemModel):
         elif (
             section
             == AccountTableModel.REPOSITORY_COLUMNS.index(
-                AccountsRepositoryInterface.COLUMN_IDENTITY_INDEX
+                IdentitiesRepositoryInterface.COLUMN_NAME
             )
             and role == Qt.DisplayRole
         ):
@@ -414,7 +465,15 @@ class AccountTableModel(QAbstractItemModel):
         elif (
             section
             == AccountTableModel.REPOSITORY_COLUMNS.index(
-                AccountsRepositoryInterface.COLUMN_CATEGORY_ID
+                AccountsRepositoryInterface.COLUMN_LEGACY_V1
+            )
+            and role == Qt.DisplayRole
+        ):
+            data = QVariant(self._("V1 Address"))
+        elif (
+            section
+            == AccountTableModel.REPOSITORY_COLUMNS.index(
+                CategoriesRepositoryInterface.COLUMN_NAME
             )
             and role == Qt.DisplayRole
         ):
@@ -422,7 +481,7 @@ class AccountTableModel(QAbstractItemModel):
 
         return data
 
-    def sort(self, column: int, order: Qt.SortOrder = None) -> None:
+    def sort(self, column: int, order: Optional[Qt.SortOrder] = None) -> None:
         """
         Sort by column number in order
 
@@ -436,6 +495,10 @@ class AccountTableModel(QAbstractItemModel):
                 if order == Qt.AscendingOrder
                 else AccountsRepositoryInterface.SORT_ORDER_DESCENDING
             )
-            self.application.preferences_repository.set(TABLE_SORT_COLUMN, str(column))
-            self.application.preferences_repository.set(TABLE_SORT_ORDER, sort_order)
+            self.application.repository.preferences.set(
+                ACCOUNTS_TABLE_SORT_COLUMN_PREFERENCES_KEY, str(column)
+            )
+            self.application.repository.preferences.set(
+                ACCOUNTS_TABLE_SORT_ORDER_PREFERENCES_KEY, sort_order
+            )
             self.init_data()
