@@ -24,7 +24,7 @@ from PyQt5.QtGui import QFont, QMovie, QPixmap
 from PyQt5.QtWidgets import QApplication, QButtonGroup, QDialog, QLineEdit, QWidget
 
 from tikka.domains.application import Application
-from tikka.domains.entities.account import AccountCryptoType
+from tikka.domains.entities.account import AccountBalance, AccountCryptoType
 from tikka.domains.entities.constants import (
     AMOUNT_UNIT_KEY,
     DATA_PATH,
@@ -98,7 +98,8 @@ class AccountImportWindow(QDialog, Ui_AccountImportDialog):
             ]
         )
 
-        self.balance: Optional[int] = None
+        self.balance: Optional[AccountBalance] = None
+        self.balance_unclaimed_uds: Optional[int] = None
         self.identity: Optional[Identity] = None
         self.smith: Optional[Smith] = None
 
@@ -395,7 +396,8 @@ class AccountImportWindow(QDialog, Ui_AccountImportDialog):
         :return:
         """
         address = self.addressValueLabel.text().strip()
-        self.balance = None
+        self.balance: Optional[AccountBalance] = None
+        self.balance_unclaimed_uds = None
         self.identity = None
         self.smith = None
 
@@ -433,7 +435,7 @@ class AccountImportWindow(QDialog, Ui_AccountImportDialog):
         if self.balance is not None:
             self.balanceValueLabel.setText(
                 self.locale().toCurrencyString(
-                    self.amount.value(self.balance), self.amount.symbol()
+                    self.amount.value(self.balance.total), self.amount.symbol()
                 )
             )
         else:
@@ -479,8 +481,11 @@ class AccountImportWindow(QDialog, Ui_AccountImportDialog):
         )
         if account:
             if self.balance:
-                account.balance = self.balance
+                account.balance = self.balance.total
+                account.balance_available = self.balance.available
+                account.balance_reserved = self.balance.reserved
                 self.application.accounts.update(account)
+
             if self.identity:
                 if self.application.identities.get(self.identity.index) is None:
                     self.application.identities.add(self.identity)
