@@ -19,8 +19,9 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, List, Optional
 
 from PyQt5 import QtGui
-from PyQt5.QtCore import QModelIndex, QMutex, QSize, Qt, pyqtSignal
+from PyQt5.QtCore import QModelIndex, QMutex, QObject, QSize, Qt, QThread, pyqtSignal
 from PyQt5.QtGui import QColor, QIcon, QKeyEvent, QPixmap, QShowEvent
+from PyQt5.QtWebEngineWidgets import QWebEnginePage
 from PyQt5.QtWidgets import (
     QApplication,
     QComboBox,
@@ -35,7 +36,10 @@ from tikka.domains.application import Application
 from tikka.domains.config import Config
 from tikka.domains.entities.account import Account
 from tikka.domains.entities.address import DisplayAddress
-from tikka.domains.entities.constants import DATA_PATH
+from tikka.domains.entities.constants import (
+    DATA_PATH,
+    DATAPOD_CESIUM_PLUS_V1_BLOCK_ZERO_HASH,
+)
 from tikka.domains.entities.events import (
     AccountEvent,
     ConnectionsEvent,
@@ -53,7 +57,6 @@ from tikka.slots.pyqt.entities.constants import (
     SELECTED_UNIT_PREFERENCES_KEY,
     TABS_PREFERENCES_KEY,
 )
-from tikka.slots.pyqt.entities.worker import AsyncQWorker
 from tikka.slots.pyqt.resources.gui.windows.main_window_rc import Ui_MainWindow
 from tikka.slots.pyqt.widgets.account import AccountWidget
 from tikka.slots.pyqt.widgets.account_table import AccountTableWidget
@@ -86,6 +89,174 @@ if TYPE_CHECKING:
     pass
 
 
+class ServerConnectionWorker(QObject):
+    finished = pyqtSignal()
+
+    def __init__(self, application):
+        super().__init__()
+        self.application = application
+
+    def run(self):
+        # Connexions synchrones ici - ça ne bloquera pas l'UI car dans un thread séparé
+        self.connect_to_node()
+        self.connect_to_indexer()
+        self.connect_to_datapod()
+        self.finished.emit()
+
+    def connect_to_node(self):
+        """
+        Connection to node
+
+        :return:
+        """
+        # init network connections
+        if self.application.config.get(Config.RANDOM_CONNECTION_AT_START_KEY) is True:
+            self.application.nodes.network_set_url_randomly()
+
+        current_node = self.application.nodes.get(
+            self.application.nodes.get_current_url()
+        )
+        if current_node is not None:
+            # connect to node
+            self.application.connections.node.connect(current_node)
+            if self.application.connections.node.is_connected():
+                node_currency = self.application.currencies.network.get_instance()
+                if (
+                    self.application.currencies.get_current().genesis_hash is not None
+                    and node_currency.genesis_hash
+                    != self.application.currencies.get_current().genesis_hash
+                ):
+                    self.application.connections.node.disconnect()
+                    logging.error("Node currency is different! Force Disconnect!")
+                else:
+                    self.fetch_data_from_network_node()
+
+    def connect_to_indexer(self):
+        """
+        Connection to indexer
+
+        :return:
+        """
+        if self.application.config.get(Config.RANDOM_CONNECTION_AT_START_KEY) is True:
+            self.application.indexers.network_set_url_randomly()
+        else:
+            current_indexer = self.application.indexers.get(
+                self.application.indexers.get_current_url()
+            )
+            if current_indexer is not None:
+                # connect to indexer
+                self.application.connections.indexer.connect(current_indexer)
+                if self.application.connections.indexer.is_connected():
+                    indexer_genesis_hash = (
+                        self.application.indexers.network_get_genesis_hash()
+                    )
+                    if (
+                        self.application.currencies.get_current().genesis_hash
+                        is not None
+                        and indexer_genesis_hash
+                        != self.application.currencies.get_current().genesis_hash
+                    ):
+                        self.application.connections.indexer.disconnect()
+                        logging.error(
+                            "Indexer currency is different! Force Disconnect!"
+                        )
+                    else:
+                        self.fetch_data_from_network_indexer()
+
+    def connect_to_datapod(self):
+        """
+        Connection to datapod
+
+        :return:
+        """
+        if self.application.config.get(Config.RANDOM_CONNECTION_AT_START_KEY) is True:
+            self.application.datapods.network_set_url_randomly()
+        else:
+            current_datapod = self.application.datapods.get(
+                self.application.datapods.get_current_url()
+            )
+            if current_datapod is not None:
+                # connect to datapod
+                self.application.connections.datapod.connect(current_datapod)
+                if self.application.connections.datapod.is_connected():
+                    datapod_genesis_hash = (
+                        self.application.datapods.network_datapod.get_genesis_hash()
+                    )
+                    if datapod_genesis_hash != DATAPOD_CESIUM_PLUS_V1_BLOCK_ZERO_HASH:
+                        self.application.connections.datapod.disconnect()
+                        logging.error(
+                            "DataPod currency is different! Force Disconnect!"
+                        )
+                    else:
+                        self.fetch_data_from_network_datapod()
+
+    def fetch_data_from_network_node(self):
+        """
+        Fetch data from the network node
+
+        :return:
+        """
+        self.application.nodes.network_fetch_current_node()
+        self.application.currencies.network_update_properties()
+
+        self.application.nodes.network_fetch_endpoints()
+        self.application.indexers.network_fetch_endpoints()
+
+        accounts = self.application.accounts.get_list()
+        try:
+            self.application.accounts.network_update_balances(accounts)
+        except Exception as exception:
+            logging.exception(exception)
+
+        addresses = [account.address for account in accounts]
+        try:
+            self.application.identities.network_update_identities(addresses)
+        except Exception as exception:
+            logging.exception(exception)
+        else:
+            identity_indice = self.application.identities.list_indice()
+            try:
+                self.application.smiths.network_update_smiths(identity_indice)
+            except Exception as exception:
+                logging.exception(exception)
+            else:
+                self.application.authorities.network_get_all()
+
+        self.application.technical_committee.network_update_members()
+        self.application.technical_committee.network_update_proposals()
+
+    def fetch_data_from_network_indexer(self):
+        """
+        Fetch data from the network indexer
+
+        :return:
+        """
+        self.application.indexers.network_fetch_current_indexer()
+
+        accounts = self.application.accounts.get_list()
+        addresses = [account.address for account in accounts]
+        try:
+            # update identity names from indexer
+            self.application.identities.network_update_identities(addresses)
+        except Exception as exception:
+            logging.exception(exception)
+
+        # update identity names for technical committee members from indexer
+        self.application.technical_committee.network_update_members()
+
+    def fetch_data_from_network_datapod(self):
+        """
+        Fetch data from the network datapod
+
+        :return:
+        """
+        self.application.datapods.network_fetch_current_datapod()
+
+        for account in self.application.accounts.get_list():
+            if account.legacy_v1:
+                self.application.profiles.network_update(account)
+
+
 class MainWindow(QMainWindow, Ui_MainWindow):
     """
     MainWindow class
@@ -191,12 +362,23 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             self._("Indexer connection status. Click to open connection tab.")
         )
         self.statusbar.addPermanentWidget(self.indexer_connection_status_icon)
+
+        # Datapod connection status icon
+        self.datapod_connection_status_icon = QPushButton()
+        self.datapod_connection_status_icon.setFlat(True)
+        self.datapod_connection_status_icon.setFixedSize(QSize(16, 16))
+        self.datapod_connection_status_icon.setToolTip(
+            self._("Indexer connection status. Click to open connection tab.")
+        )
+        self.statusbar.addPermanentWidget(self.datapod_connection_status_icon)
+
         self.init_connection_status()
 
         # slots
         self.unit_combo_box.activated.connect(self._on_unit_changed)
         self.node_connection_status_icon.clicked.connect(self.add_connection_tab)
         self.indexer_connection_status_icon.clicked.connect(self.add_connection_tab)
+        self.datapod_connection_status_icon.clicked.connect(self.add_connection_tab)
 
         # application events
         self.application.event_dispatcher.add_event_listener(
@@ -227,40 +409,29 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             ConnectionsEvent.EVENT_TYPE_INDEXER_DISCONNECTED,
             self._on_indexer_disconnected,
         )
-
-        #####################################
-        # ASYNC WORKERS
-        #####################################
-        self.connect_to_node_async_worker = AsyncQWorker(
-            self.connect_to_node, self.mutex
+        self.application.event_dispatcher.add_event_listener(
+            ConnectionsEvent.EVENT_TYPE_DATAPOD_CONNECTED, self._on_datapod_connected
         )
-        self.connect_to_node_async_worker.finished.connect(
-            self._on_finished_connect_to_node
-        )
-        # async connect to indexer
-        self.connect_to_indexer_async_worker = AsyncQWorker(
-            self.connect_to_indexer, self.mutex
-        )
-        self.connect_to_indexer_async_worker.finished.connect(
-            self._on_finished_connect_to_indexer
-        )
-        # fetch data from network
-        self.fetch_data_from_network_node_async_qworker = AsyncQWorker(
-            self.fetch_data_from_network_node, self.mutex
-        )
-        self.fetch_data_from_network_node_async_qworker.finished.connect(
-            self._on_finished_fetch_data_from_network_node
-        )
-        self.fetch_data_from_network_indexer_async_qworker = AsyncQWorker(
-            self.fetch_data_from_network_indexer, self.mutex
-        )
-        self.fetch_data_from_network_indexer_async_qworker.finished.connect(
-            self._on_finished_fetch_data_from_network_indexer
+        self.application.event_dispatcher.add_event_listener(
+            ConnectionsEvent.EVENT_TYPE_DATAPOD_DISCONNECTED,
+            self._on_datapod_disconnected,
         )
 
         # open saved tabs
         self.init_tabs()
 
+        # ASYNC THREAD AND WORKER
+        self.connection_thread = QThread()
+        self.connection_worker = ServerConnectionWorker(self.application)
+        self.connection_worker.moveToThread(self.connection_thread)
+
+        # Connect signals
+        self.connection_thread.started.connect(self.connection_worker.run)
+        self.connection_worker.finished.connect(self.connection_thread.quit)
+        self.connection_worker.finished.connect(self.connection_worker.deleteLater)
+        self.connection_worker.finished.connect(self.on_servers_connected)
+        self.connection_thread.finished.connect(self.connection_thread.deleteLater)
+
     def showEvent(self, event: QShowEvent):
         """
         Triggered when the window is shown
@@ -279,8 +450,9 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         :return:
         """
         self.statusbar.showMessage(self._("Connecting to servers..."), 10000)
-        self.connect_to_node_async_worker.start()
-        self.connect_to_indexer_async_worker.start()
+        QApplication.processEvents()
+
+        self.async_connect_to_servers()
 
     def keyPressEvent(self, event: QKeyEvent) -> None:
         """
@@ -296,15 +468,31 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         ):
             self.close_current_tab()
 
-    def closeEvent(
-        self, event: QtGui.QCloseEvent  # pylint: disable=unused-argument
-    ) -> None:
+    def cleanup(self):
+        """
+        Clean up all WebEngine resources
+
+        :return:
+        """
+        # Clean up all AccountWidget tabs
+        for index in range(self.tabWidget.count()):
+            widget = self.tabWidget.widget(index)
+            if isinstance(widget, AccountWidget) and hasattr(
+                widget, "profile_web_view"
+            ):
+                widget.profile_web_view.setPage(None)
+                widget.profile_web_view.deleteLater()
+
+    def closeEvent(self, event: QtGui.QCloseEvent) -> None:
         """
         Override close event
 
         :param event:
         :return:
         """
+        # Clean up WebEngine resources first
+        self.cleanup()
+
         # save tabs in repository
         self.save_tabs()
 
@@ -314,6 +502,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         )
 
         self.application.close()
+        event.accept()
 
     def init_units(self) -> None:
         """
@@ -365,6 +554,15 @@ class MainWindow(QMainWindow, Ui_MainWindow):
                 QIcon(QPixmap(ICON_NETWORK_DISCONNECTED))
             )
 
+        if self.application.connections.datapod.is_connected():
+            self.datapod_connection_status_icon.setIcon(
+                QIcon(QPixmap(ICON_NETWORK_CONNECTED))
+            )
+        else:
+            self.datapod_connection_status_icon.setIcon(
+                QIcon(QPixmap(ICON_NETWORK_DISCONNECTED))
+            )
+
     def init_tabs(self):
         """
         Init tabs from repository
@@ -437,6 +635,13 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         :param index: Index of tab requested to close
         :return:
         """
+        widget = self.tabWidget.widget(index)
+
+        # Clean up WebEngineView if it's an AccountWidget
+        if isinstance(widget, AccountWidget) and hasattr(widget, "profile_web_view"):
+            widget.profile_web_view.setPage(QWebEnginePage())
+            widget.profile_web_view.deleteLater()
+
         self.tabWidget.removeTab(index)
 
     def close_current_tab(self) -> None:
@@ -445,6 +650,16 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 
         :return:
         """
+        current_index = self.tabWidget.currentIndex()
+        if current_index >= 0:
+            widget = self.tabWidget.widget(current_index)
+            # Clean up WebEngineView if it's an AccountWidget
+            if isinstance(widget, AccountWidget) and hasattr(
+                widget, "profile_web_view"
+            ):
+                widget.profile_web_view.setPage(QWebEnginePage())
+                widget.profile_web_view.deleteLater()
+
         self.tabWidget.removeTab(self.tabWidget.currentIndex())
 
     def add_account_tree_tab(self) -> None:
@@ -642,7 +857,9 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         self.repository_data_updated.connect(
             connection_widget._on_finished_fetch_indexer_from_network
         )
-
+        self.repository_data_updated.connect(
+            connection_widget._on_finished_fetch_datapod_from_network
+        )
         self.tabWidget.setCurrentIndex(self.tabWidget.count() - 1)
 
     def add_servers_tab(self):
@@ -712,7 +929,9 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         self.repository_data_updated.connect(
             technical_committee_widget._on_fetch_members_from_network_async_worker_finished
         )
-
+        self.repository_data_updated.connect(
+            technical_committee_widget._on_fetch_proposals_from_network_async_worker_finished
+        )
         self.tabWidget.setCurrentIndex(self.tabWidget.count() - 1)
 
     def update_title(self):
@@ -892,8 +1111,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         logging.debug("repository_data_updated. Emit signal to widgets.")
 
         # connect to servers
-        self.connect_to_node_async_worker.start()
-        self.connect_to_indexer_async_worker.start()
+        self.async_connect_to_servers()
 
         # update default dir preference
         self.application.repository.preferences.set(
@@ -1014,8 +1232,6 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         :return:
         """
         self.node_connection_status_icon.setIcon(QIcon(ICON_NETWORK_CONNECTED))
-        self.statusbar.showMessage(self._("Loading data from network..."), 3000)
-        self.fetch_data_from_network_node_async_qworker.start()
 
     def _on_node_disconnected(self, _=None):
         """
@@ -1041,6 +1257,22 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         self.indexer_connection_status_icon.setIcon(QIcon(ICON_NETWORK_DISCONNECTED))
 
+    def _on_datapod_connected(self, _=None):
+        """
+        Triggered when datapod is connected
+
+        :return:
+        """
+        self.datapod_connection_status_icon.setIcon(QIcon(ICON_NETWORK_CONNECTED))
+
+    def _on_datapod_disconnected(self, _=None):
+        """
+        Triggered when datapod is disconnected
+
+        :return:
+        """
+        self.datapod_connection_status_icon.setIcon(QIcon(ICON_NETWORK_DISCONNECTED))
+
     def get_tab_widgets_by_class(self, widget_class: Any) -> List[QWidget]:
         """
         Return a list of widget which are instance of widget_class
@@ -1081,22 +1313,18 @@ class MainWindow(QMainWindow, Ui_MainWindow):
                 return widget
         return None
 
-    def connect_to_node(self):
-
-        # init network connections
-        if self.application.config.get(Config.RANDOM_CONNECTION_AT_START_KEY) is True:
-            self.application.nodes.set_current_url_randomly()
-        else:
-            current_node = self.application.nodes.get(
-                self.application.nodes.get_current_url()
-            )
-            if current_node is not None:
-                # connect to node
-                self.application.connections.node.connect(current_node)
-
-    def _on_finished_connect_to_node(self):
+    def async_connect_to_servers(self):
         """
-        Triggered when connection to node is finished
+        Connection to servers
+
+        :return:
+        """
+        # Start thread (non-blocking)
+        self.connection_thread.start()
+
+    def on_servers_connected(self):
+        """
+        Triggered when all connections are done
 
         :return:
         """
@@ -1104,91 +1332,18 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             self.application.event_dispatcher.dispatch_event(
                 ConnectionsEvent(ConnectionsEvent.EVENT_TYPE_NODE_CONNECTED)
             )
-
-    def connect_to_indexer(self):
-        if self.application.config.get(Config.RANDOM_CONNECTION_AT_START_KEY) is True:
-            self.application.indexers.set_current_url_randomly()
-        else:
-            current_indexer = self.application.indexers.get(
-                self.application.indexers.get_current_url()
-            )
-            if current_indexer is not None:
-                # connect to indexer
-                self.application.connections.indexer.connect(current_indexer)
-
-    def _on_finished_connect_to_indexer(self):
-        """
-        Triggered when connection to indexer is finished
-
-        :return:
-        """
         if self.application.connections.indexer.is_connected():
             self.application.event_dispatcher.dispatch_event(
                 ConnectionsEvent(ConnectionsEvent.EVENT_TYPE_INDEXER_CONNECTED)
             )
+        if self.application.connections.datapod.is_connected():
+            self.application.event_dispatcher.dispatch_event(
+                ConnectionsEvent(ConnectionsEvent.EVENT_TYPE_DATAPOD_CONNECTED)
+            )
 
-    def fetch_data_from_network_node(self):
-        """
-        Fetch data from the network node
-
-        :return:
-        """
-        self.application.nodes.network_fetch_current_node()
-        self.application.currencies.network_update_properties()
-
-        self.application.nodes.network_fetch_endpoints()
-        self.application.indexers.network_fetch_endpoints()
-
-        accounts = self.application.accounts.get_list()
-        try:
-            self.application.accounts.network_update_balances(accounts)
-        except Exception as exception:
-            logging.exception(exception)
-
-        addresses = [account.address for account in accounts]
-        try:
-            self.application.identities.network_update_identities(addresses)
-        except Exception as exception:
-            logging.exception(exception)
-        else:
-            identity_indice = self.application.identities.list_indice()
-            try:
-                self.application.smiths.network_update_smiths(identity_indice)
-            except Exception as exception:
-                logging.exception(exception)
-            else:
-                self.application.authorities.network_get_all()
-
-        self.application.technical_committee.network_update_members()
-        self.application.technical_committee.network_update_proposals()
-
-    def _on_finished_fetch_data_from_network_node(self):
-        """
-        Triggered when async request fetch_data_from_network_node is finished
-
-        :return:
-        """
-        self.statusbar.showMessage(self._("Data updated from network node."), 3000)
+        self.statusbar.showMessage(self._("Data updated from servers."), 10000)
         self.repository_data_updated.emit()
-        logging.debug("Main window network fetch finished....emit signal")
-
-    def fetch_data_from_network_indexer(self):
-        """
-        Fetch data from the network indexer
-
-        :return:
-        """
-        self.application.indexers.network_fetch_current_indexer()
-
-    def _on_finished_fetch_data_from_network_indexer(self):
-        """
-        Triggered when async request fetch_data_from_network_indexer is finished
-
-        :return:
-        """
-        self.statusbar.showMessage(self._("Data updated from network indexer."), 3000)
-        self.repository_data_updated.emit()
-        logging.debug("Main window network fetch finished....emit signal")
+        logging.debug("Main window network servers data fetch finished....emit signal")
 
 
 if __name__ == "__main__":
