@@ -12,26 +12,27 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+import logging
 import sys
 from pathlib import Path
 from typing import TYPE_CHECKING, Optional
 
-from PyQt5.QtCore import QTimer
+from PyQt5.QtCore import QMutex, QTimer
 from PyQt5.QtGui import QFont
 from PyQt5.QtWidgets import QApplication, QDialog, QFileDialog, QLineEdit, QWidget
-from substrateinterface import Keypair, KeypairType
 
 from tikka.domains.application import Application
+from tikka.domains.entities.account import Account, AccountCryptoType
 from tikka.domains.entities.constants import DATA_PATH, WALLETS_PASSWORD_LENGTH
 from tikka.domains.entities.wallet import V1FileWallet
-from tikka.interfaces.adapters.repository.preferences import (
-    WALLET_LOAD_DEFAULT_DIRECTORY,
-)
+from tikka.libs.keypair import Keypair
 from tikka.libs.secret import generate_alphabetic
 from tikka.slots.pyqt.entities.constants import (
     ADDRESS_MONOSPACE_FONT_NAME,
     DEBOUNCE_TIME,
+    WALLET_LOAD_DEFAULT_DIRECTORY_PREFERENCES_KEY,
 )
+from tikka.slots.pyqt.entities.worker import AsyncQWorker
 from tikka.slots.pyqt.resources.gui.windows.v1_file_import_rc import (
     Ui_V1FileImportDialog,
 )
@@ -48,12 +49,14 @@ class V1FileImportWindow(QDialog, Ui_V1FileImportDialog):
     def __init__(
         self,
         application: Application,
+        mutex: QMutex,
         parent: Optional[QWidget] = None,
     ):
         """
         Init V1 import wallet window
 
         :param application: Application instance
+        :param mutex: QMutex instance
         :param parent: QWidget instance
         """
         super().__init__(parent=parent)
@@ -62,6 +65,7 @@ class V1FileImportWindow(QDialog, Ui_V1FileImportDialog):
         self.application = application
         self.v1_file_wallet: Optional[V1FileWallet] = None
         self._ = self.application.translator.gettext
+        self.mutex = mutex
 
         # set monospace font to address fields
         monospace_font = QFont(ADDRESS_MONOSPACE_FONT_NAME)
@@ -82,6 +86,13 @@ class V1FileImportWindow(QDialog, Ui_V1FileImportDialog):
         # debounce timer
         self.debounce_timer = QTimer()
         self.debounce_timer.timeout.connect(self._load_v1_file_wallet)
+        # Create a QWorker object
+        self.network_check_legacy_v1_async_qworker = AsyncQWorker(
+            self.network_check_legacy_v1, self.mutex
+        )
+        self.network_check_legacy_v1_async_qworker.finished.connect(
+            self._on_finished_network_check_legacy_v1
+        )
 
         # fill form
         self.buttonBox.button(self.buttonBox.Ok).setEnabled(False)
@@ -116,13 +127,14 @@ class V1FileImportWindow(QDialog, Ui_V1FileImportDialog):
         """
         # clear path
         self.pathValueLabel.setText("")
+        self.filePasswordLineEdit.setText("")
 
         # open file dialog
         filepath = self.open_file_dialog()
         if filepath is not None:
             # update default dir preference
-            self.application.preferences_repository.set(
-                WALLET_LOAD_DEFAULT_DIRECTORY,
+            self.application.repository.preferences.set(
+                WALLET_LOAD_DEFAULT_DIRECTORY_PREFERENCES_KEY,
                 str(Path(filepath).expanduser().absolute().parent),
             )
             self.pathValueLabel.setText(filepath)
@@ -139,7 +151,7 @@ class V1FileImportWindow(QDialog, Ui_V1FileImportDialog):
 
         password = self.filePasswordLineEdit.text().strip()
         try:
-            self.v1_file_wallet = self.application.file_wallets_repository.load(
+            self.v1_file_wallet = self.application.repository.v1_file_wallets.load(
                 self.pathValueLabel.text(), password
             )
         except Exception:
@@ -153,11 +165,15 @@ class V1FileImportWindow(QDialog, Ui_V1FileImportDialog):
             return
 
         # wallet decrypted
-        self.v1AddressValueLabel.setText(self.v1_file_wallet.signing_key.pubkey)
         keypair = Keypair.create_from_seed(
             seed_hex=self.v1_file_wallet.signing_key.seed.hex(),
             ss58_format=self.application.currencies.get_current().ss58_format,
-            crypto_type=KeypairType.ED25519,
+            crypto_type=AccountCryptoType.ED25519,
+        )
+        self.v1AddressValueLabel.setText(
+            Account(keypair.ss58_address).get_v1_address(
+                self.application.currencies.get_current().ss58_format
+            )
         )
         self.addressValueLabel.setText(keypair.ss58_address)
         if self.application.accounts.get_by_address(keypair.ss58_address) is not None:
@@ -165,7 +181,7 @@ class V1FileImportWindow(QDialog, Ui_V1FileImportDialog):
             self.buttonBox.button(self.buttonBox.Ok).setEnabled(False)
         else:
             self.errorLabel.setText("")
-            self.buttonBox.button(self.buttonBox.Ok).setEnabled(True)
+            self.network_check_legacy_v1_async_qworker.start()
 
     def open_file_dialog(self) -> Optional[str]:
         """
@@ -173,8 +189,8 @@ class V1FileImportWindow(QDialog, Ui_V1FileImportDialog):
 
         :return:
         """
-        default_dir = self.application.preferences_repository.get(
-            WALLET_LOAD_DEFAULT_DIRECTORY
+        default_dir = self.application.repository.preferences.get(
+            WALLET_LOAD_DEFAULT_DIRECTORY_PREFERENCES_KEY
         )
         if default_dir is not None:
             default_dir = str(Path(default_dir).expanduser().absolute())
@@ -199,6 +215,33 @@ class V1FileImportWindow(QDialog, Ui_V1FileImportDialog):
             self.debounce_timer.stop()
         self.debounce_timer.start(DEBOUNCE_TIME)
 
+    def network_check_legacy_v1(self):
+        """
+        Check if account is really a known legacy v1 account
+
+        :return:
+        """
+        address = self.addressValueLabel.text().strip()
+        try:
+            self.is_legacy_v1 = self.application.accounts.network_is_legacy_v1(address)
+        except Exception as exception:
+            self.errorLabel.setText(self._(str(exception)))
+            logging.exception(exception)
+
+    def _on_finished_network_check_legacy_v1(self):
+        """
+        Triggered when async request network_check_legacy_v1 is finished
+
+        :return:
+        """
+        if self.is_legacy_v1 is not None:
+            if not self.is_legacy_v1:
+                self.errorLabel.setText(self._("V1 account unknown!"))
+                self.buttonBox.button(self.buttonBox.Ok).setEnabled(False)
+            else:
+                self.errorLabel.setText("")
+                self.buttonBox.button(self.buttonBox.Ok).setEnabled(True)
+
     def _on_accepted_button(self):
         """
         Triggered when user click on cancel button
@@ -223,6 +266,4 @@ class V1FileImportWindow(QDialog, Ui_V1FileImportDialog):
 if __name__ == "__main__":
     qapp = QApplication(sys.argv)
     application_ = Application(DATA_PATH)
-    V1FileImportWindow(
-        application_,
-    ).exec_()
+    V1FileImportWindow(application_, QMutex()).exec_()
