@@ -16,16 +16,16 @@ import logging
 import sys
 from typing import Optional
 
-from duniterpy.key import SigningKey
 from PyQt5.QtCore import QTimer
 from PyQt5.QtGui import QFont
 from PyQt5.QtWidgets import QApplication, QDialog, QLineEdit, QMessageBox, QWidget
-from substrateinterface import Keypair, KeypairType
 
 from tikka.domains.application import Application
-from tikka.domains.entities.account import Account
+from tikka.domains.entities.account import Account, AccountCryptoType
 from tikka.domains.entities.constants import DATA_PATH, WALLETS_PASSWORD_LENGTH
+from tikka.libs.keypair import Keypair
 from tikka.libs.secret import generate_alphabetic
+from tikka.libs.signing_key_v1 import SigningKey
 from tikka.slots.pyqt.entities.constants import (
     ADDRESS_MONOSPACE_FONT_NAME,
     DEBOUNCE_TIME,
@@ -136,7 +136,7 @@ class V1WalletRestoreWindow(QDialog, Ui_V1WalletRestoreDialog):
             keypair = Keypair.create_from_seed(
                 seed_hex=signing_key.seed.hex(),
                 ss58_format=self.application.currencies.get_current().ss58_format,
-                crypto_type=KeypairType.ED25519,
+                crypto_type=AccountCryptoType.ED25519,
             )
         except Exception as exception:
             logging.exception(exception)
@@ -162,7 +162,11 @@ class V1WalletRestoreWindow(QDialog, Ui_V1WalletRestoreDialog):
             self.storedPasswordFrame.hide()
             self.passwordFrame.show()
 
-        self.v1AddressValueLabel.setText(signing_key.pubkey)
+        self.v1AddressValueLabel.setText(
+            Account(address).get_v1_address(
+                self.application.currencies.get_current().ss58_format
+            )
+        )
         self.buttonBox.button(self.buttonBox.Ok).setEnabled(True)
 
     def on_show_button_clicked(self):
@@ -204,7 +208,7 @@ class V1WalletRestoreWindow(QDialog, Ui_V1WalletRestoreDialog):
         keypair = Keypair.create_from_seed(
             seed_hex=signing_key.seed.hex(),
             ss58_format=self.application.currencies.get_current().ss58_format,
-            crypto_type=KeypairType.ED25519,
+            crypto_type=AccountCryptoType.ED25519,
         )
         address = keypair.ss58_address
 
@@ -247,7 +251,7 @@ if __name__ == "__main__":
     account_ = Account(
         "5GAT6CJW8yVKwUuQc7sM5Kk9GZVTpbZYk9PfjNXtvnNgAJZ1",
         name="test name",
-        crypto_type=KeypairType.ED25519,
+        crypto_type=AccountCryptoType.ED25519,
         file_import=True,
     )
     V1WalletRestoreWindow(application_, account_).exec_()
