@@ -26,19 +26,17 @@ from PyQt5.QtWidgets import (
     QMessageBox,
     QWidget,
 )
-from substrateinterface import Keypair, KeypairType
 
 from tikka.domains.application import Application
-from tikka.domains.entities.account import Account
+from tikka.domains.entities.account import Account, AccountCryptoType
 from tikka.domains.entities.constants import DATA_PATH, WALLETS_PASSWORD_LENGTH
 from tikka.domains.entities.wallet import V1FileWallet
-from tikka.interfaces.adapters.repository.preferences import (
-    WALLET_LOAD_DEFAULT_DIRECTORY,
-)
+from tikka.libs.keypair import Keypair
 from tikka.libs.secret import generate_alphabetic
 from tikka.slots.pyqt.entities.constants import (
     ADDRESS_MONOSPACE_FONT_NAME,
     DEBOUNCE_TIME,
+    WALLET_LOAD_DEFAULT_DIRECTORY_PREFERENCES_KEY,
 )
 from tikka.slots.pyqt.resources.gui.windows.v1_wallet_restore_from_file_rc import (
     Ui_V1WalletRestoreFromFileDialog,
@@ -137,8 +135,8 @@ class V1WalletRestoreFromFileWindow(QDialog, Ui_V1WalletRestoreFromFileDialog):
         filepath = self.open_file_dialog()
         if filepath is not None:
             # update default dir preference
-            self.application.preferences_repository.set(
-                WALLET_LOAD_DEFAULT_DIRECTORY,
+            self.application.repository.preferences.set(
+                WALLET_LOAD_DEFAULT_DIRECTORY_PREFERENCES_KEY,
                 str(Path(filepath).expanduser().absolute().parent),
             )
             self.pathValueLabel.setText(filepath)
@@ -155,7 +153,7 @@ class V1WalletRestoreFromFileWindow(QDialog, Ui_V1WalletRestoreFromFileDialog):
 
         password = self.filePasswordLineEdit.text().strip()
         try:
-            self.v1_file_wallet = self.application.file_wallets_repository.load(
+            self.v1_file_wallet = self.application.repository.v1_file_wallets.load(
                 self.pathValueLabel.text(), password
             )
         except Exception:
@@ -169,12 +167,17 @@ class V1WalletRestoreFromFileWindow(QDialog, Ui_V1WalletRestoreFromFileDialog):
             return
 
         # wallet decrypted
-        self.v1AddressValueLabel.setText(self.v1_file_wallet.signing_key.pubkey)
         keypair = Keypair.create_from_seed(
             seed_hex=self.v1_file_wallet.signing_key.seed.hex(),
             ss58_format=self.application.currencies.get_current().ss58_format,
-            crypto_type=KeypairType.ED25519,
+            crypto_type=AccountCryptoType.ED25519,
         )
+        self.v1AddressValueLabel.setText(
+            Account(keypair.ss58_address).get_v1_address(
+                self.application.currencies.get_current().ss58_format
+            )
+        )
+
         # if file address is not account address...
         if keypair.ss58_address != self.account.address:
             self.errorLabel.setText(self._("File address is not the account address!"))
@@ -202,8 +205,8 @@ class V1WalletRestoreFromFileWindow(QDialog, Ui_V1WalletRestoreFromFileDialog):
 
         :return:
         """
-        default_dir = self.application.preferences_repository.get(
-            WALLET_LOAD_DEFAULT_DIRECTORY
+        default_dir = self.application.repository.preferences.get(
+            WALLET_LOAD_DEFAULT_DIRECTORY_PREFERENCES_KEY
         )
         if default_dir is not None:
             default_dir = str(Path(default_dir).expanduser().absolute())
@@ -241,7 +244,7 @@ class V1WalletRestoreFromFileWindow(QDialog, Ui_V1WalletRestoreFromFileDialog):
         keypair = Keypair.create_from_seed(
             seed_hex=self.v1_file_wallet.signing_key.seed.hex(),
             ss58_format=self.application.currencies.get_current().ss58_format,
-            crypto_type=KeypairType.ED25519,
+            crypto_type=AccountCryptoType.ED25519,
         )
         address = keypair.ss58_address
 
@@ -285,7 +288,7 @@ if __name__ == "__main__":
     account_ = Account(
         "5GAT6CJW8yVKwUuQc7sM5Kk9GZVTpbZYk9PfjNXtvnNgAJZ1",
         name="test name",
-        crypto_type=KeypairType.ED25519,
+        crypto_type=AccountCryptoType.ED25519,
         file_import=True,
     )
     V1WalletRestoreFromFileWindow(application_, account_).exec_()
