@@ -42,7 +42,7 @@ from PyQt5.QtWidgets import (
 )
 
 from tikka.domains.application import Application
-from tikka.domains.entities.account import Account, AccountCryptoType
+from tikka.domains.entities.account import Account, AccountBalance, AccountCryptoType
 from tikka.domains.entities.constants import (
     AMOUNT_UNIT_KEY,
     DATA_PATH,
@@ -200,7 +200,7 @@ class VaultImportByMnemonicWindow(QDialog, Ui_VaultImportByMnemonicDialog):
             ]
         )
 
-        self.balance: Optional[int] = None
+        self.balance: Optional[AccountBalance] = None
         self.identity: Optional[Identity] = None
         self.smith: Optional[Smith] = None
         self.derived_accounts: List[Account] = []
@@ -507,7 +507,7 @@ class VaultImportByMnemonicWindow(QDialog, Ui_VaultImportByMnemonicDialog):
         if self.balance is not None:
             self.balanceValueLabel.setText(
                 self.locale().toCurrencyString(
-                    self.amount.value(self.balance), self.amount.symbol()
+                    self.amount.value(self.balance.total), self.amount.symbol()
                 )
             )
         else:
@@ -647,8 +647,11 @@ class VaultImportByMnemonicWindow(QDialog, Ui_VaultImportByMnemonicDialog):
 
         if root_account:
             if self.balance:
-                root_account.balance = self.balance
+                root_account.balance = self.balance.total
+                root_account.balance_available = self.balance.available
+                root_account.balance_reserved = self.balance.reserved
                 self.application.accounts.update(root_account)
+
             if self.identity:
                 if self.application.identities.get(self.identity.index) is None:
                     self.application.identities.add(self.identity)
@@ -666,6 +669,8 @@ class VaultImportByMnemonicWindow(QDialog, Ui_VaultImportByMnemonicDialog):
             )
             if existing_account is not None:
                 existing_account.balance = derived_account.balance
+                existing_account.balance_available = derived_account.balance_available
+                existing_account.balance_reserved = derived_account.balance_reserved
                 self.application.accounts.update(existing_account)
             else:
                 account = self.application.accounts.create_new_account(
@@ -678,6 +683,8 @@ class VaultImportByMnemonicWindow(QDialog, Ui_VaultImportByMnemonicDialog):
                     add_event=False,
                 )
                 account.balance = derived_account.balance
+                account.balance_available = derived_account.balance_available
+                account.balance_reserved = derived_account.balance_reserved
                 self.application.accounts.update(account)
 
         for identity in self.identities.values():
